@@ -10,7 +10,7 @@ from astrorapid.ANTARES_object.LAobject import LAobject
 
 class InputLightCurve(object):
     def __init__(self, mjd, flux, fluxerr, passband, photflag, ra, dec, objid, redshift=None, mwebv=None,
-                 known_redshift=True, training_set_parameters=None):
+                 known_redshift=True, training_set_parameters=None, calculate_t0=None):
         """
 
         Parameters
@@ -42,6 +42,9 @@ class InputLightCurve(object):
         training_set_parameters : dict
             Optional parameter. If this is not None, then determine the explosion time, t0, for full the training set.
             The dictionary must have the following keys: {class_number, peakmjd}
+        calculate_t0 : bool or None
+            Optional parameter. If this is False, t0 will not be computed
+            even if the training_set_parameters argument is set.
         """
 
         self.mjd = np.array(mjd)
@@ -56,6 +59,7 @@ class InputLightCurve(object):
         self.mwebv = mwebv
         self.known_redshift = known_redshift
         self.training_set_parameters = training_set_parameters
+        self.calculate_t0 = calculate_t0
         if training_set_parameters is not None:
             self.class_number = training_set_parameters['class_number']
             self.peakmjd = training_set_parameters['peakmjd']
@@ -93,19 +97,20 @@ class InputLightCurve(object):
     def compute_t0(self, outlc):
         """ Calculate the explosion time for the trianing set if certain conditions are met. """
         calc_params = True
-        inrange_mask = self.t < self.peakmjd
+        peak_time = self.peakmjd - self.trigger_mjd
+        early_time = peak_time - 5
+        inrange_mask = self.t < early_time
         if self.class_number in [70, 80, 82, 83]:  # No t0 if model types (AGN, RRlyrae, Eclipsing Binaries)
             calc_params = False
         elif self.peakmjd - self.trigger_mjd < 0:  # No t0 if trigger to peak time is small
             calc_params = False
-        elif len(self.t[inrange_mask]) < 3:  # No t0 if not At least 3 points before peak
+        elif len(self.t[inrange_mask]) < 3:  # No t0 if not At least 3 points before peak/early_time
             calc_params = False
-        elif len(self.t[self.t < 0]) < 3:  # No t0 if there are less than three points before trigger
+        elif len(self.t[self.t < 0]) < 4:  # No t0 if there are less than 4 points before trigger
             calc_params = False
 
         if calc_params:
-            earlytime = self.peakmjd - self.trigger_mjd
-            fit_func, parameters = model_early_lightcurve.fit_early_lightcurve(outlc, earlytime)
+            fit_func, parameters = model_early_lightcurve.fit_early_lightcurve(outlc, early_time)
         else:
             parameters = {pb: [-99, -99, -99] for pb in self.passband}
 
@@ -131,8 +136,9 @@ class InputLightCurve(object):
         outlc.meta = {'redshift': self.redshift, 'b': self.b, 'mwebv': self.mwebv, 'trigger_mjd': self.trigger_mjd}
 
         if self.training_set_parameters is not None:
-            t0 = self.compute_t0(outlc)
-            outlc.meta['t0'] = t0
+            if self.calculate_t0 is not False:
+                t0 = self.compute_t0(outlc)
+                outlc.meta['t0'] = t0
             outlc.meta['peakmjd'] = self.peakmjd
             outlc.meta['class_num'] = self.class_number
 
